@@ -38,11 +38,4 @@ setMethodS3("setCachePath", "default", function(dirs=NULL, path=NULL, ...) {
   names(opts) <- name;
   ovalue <- options(opts);
   invisible(ovalue);
-})
-
-
-############################################################################
-# HISTORY:
-# 2007-01-24
-# o Created.
-############################################################################
+}, export=FALSE)
